import { InjectionToken, Component, ChangeDetectionStrategy, Optional, Inject, forwardRef, ChangeDetectorRef, NgModule } from '@angular/core';
import { ControlContainer, FormGroupDirective, ReactiveFormsModule } from '@angular/forms';
import { DateRange, MatDatepickerContent, MatCalendar, MatDatepickerModule } from '@angular/material/datepicker';
import { MatFormFieldModule } from '@angular/material/form-field';
import { MatInputModule } from '@angular/material/input';

const MAT_DATEPICKER_TIME_CONTROL_NAME = new InjectionToken('custom form control name for datepicker header input');
function _handleUserSelection(event) {
    const selection = this._model.selection;
    const value = event.value;
    const isRange = selection instanceof DateRange;
    // If we're selecting a range and we have a selection strategy, always pass the value through
    // there. Otherwise don't assign null values to the model, unless we're selecting a range.
    // A null value when picking a range means that the user cancelled the selection (e.g. by
    // pressing escape), whereas when selecting a single value it means that the value didn't
    // change. This isn't very intuitive, but it's here for backwards-compatibility.
    if (isRange && this._rangeSelectionStrategy) {
        const newSelection = this._rangeSelectionStrategy.selectionFinished(value, selection, event.event);
        this._model.updateSelection(newSelection, this);
    }
    else if (value && (isRange ||
        !this._dateAdapter.sameDate(value, selection))) {
        this._model.add(value);
    }
    // if ((!this._model || this._model.isComplete()) && !this.disableAutoClose) {
    //     this.datepicker.close();
    // }
}

class MatDatepickerTimeHeaderComponent {
    constructor(parentFormDir, timeInputControlName, matDatepickerContent, calendar, changeDetectorRef) {
        this.parentFormDir = parentFormDir;
        this.timeInputControlName = timeInputControlName;
        this.matDatepickerContent = matDatepickerContent;
        this.calendar = calendar;
        // rangepicker not supported (no place in heafer)
        this.throwIfRange();
        // by default, after selecting a date, the picker closes automaticaly. We are overriding it to allow time selection
        this.disableAutoClose();
        //this.calendar.stateChanges.subscribe(() => changeDetectorRef.markForCheck());
    }
    get isRange() {
        return this.calendar.selected instanceof DateRange;
    }
    get timeControl() {
        return this.parentFormDir.form.get(this.timeInputControlName || 'time');
    }
    throwIfRange() {
        if (this.isRange) {
            throw ('mat-datepicker-time-header-component is not yet supported for date-range picker');
        }
    }
    disableAutoClose() {
        //; (this.matDatepickerContent as any).disableAutoClose = true;
        //MatDatepickerContent.prototype._handleUserSelection = _handleUserSelection;
        this.matDatepickerContent._handleUserSelection = _handleUserSelection;
    }
}
MatDatepickerTimeHeaderComponent.decorators = [
    { type: Component, args: [{
                selector: 'mat-datepicker-time-header',
                template: "<mat-calendar-header>\r\n    <mat-form-field appearance=\"outline\">\r\n        <mat-label>time</mat-label>\r\n        <input type=\"time\" [formControl]=\"timeControl\" matInput>\r\n    </mat-form-field>\r\n</mat-calendar-header>",
                changeDetection: ChangeDetectionStrategy.OnPush,
                providers: [{ provide: ControlContainer, useExisting: FormGroupDirective }],
                styles: [".mat-form-field{max-width:90px;font-size:.9em}:host::ng-deep.mat-form-field-wrapper{margin-bottom:-1.25em}:host::ng-deep .mat-form-field-flex>.mat-form-field-infix{padding:.4em 0!important}:host::ng-deep .mat-form-field-label-wrapper{top:-1.4em}:host::ng-deep .mat-form-field-appearance-outline.mat-form-field-can-float.mat-form-field-should-float .mat-form-field-label{transform:translateY(-1.1em) scale(.75);width:133.33333%}input[type=time]::-webkit-calendar-picker-indicator{background:none;display:none}"]
            },] }
];
MatDatepickerTimeHeaderComponent.ctorParameters = () => [
    { type: FormGroupDirective },
    { type: String, decorators: [{ type: Optional }, { type: Inject, args: [MAT_DATEPICKER_TIME_CONTROL_NAME,] }, { type: Optional }] },
    { type: MatDatepickerContent },
    { type: MatCalendar, decorators: [{ type: Inject, args: [forwardRef(() => MatCalendar),] }] },
    { type: ChangeDetectorRef }
];

class MatDatepickerTimeHeaderModule {
}
MatDatepickerTimeHeaderModule.decorators = [
    { type: NgModule, args: [{
                declarations: [MatDatepickerTimeHeaderComponent],
                imports: [
                    ReactiveFormsModule,
                    MatDatepickerModule,
                    MatFormFieldModule,
                    MatInputModule
                ],
                exports: [MatDatepickerTimeHeaderComponent]
            },] }
];

/*
 * Public API Surface of mat-datepicker-time-header
 */

/**
 * Generated bundle index. Do not edit.
 */

export { MAT_DATEPICKER_TIME_CONTROL_NAME, MatDatepickerTimeHeaderComponent, MatDatepickerTimeHeaderModule };
//# sourceMappingURL=mat-datepicker-time-header.js.map
